@@ -22,9 +22,9 @@
 ## Return H-2 or L-inf norm of @acronym{LTI} model.
 ##
 ## @strong{Algorithm}@*
-## Uses @uref{https://github.com/SLICOT/SLICOT-Reference, SLICOT AB13BD and AB13DD},
-## Copyright (c) 2020, SLICOT, available under the BSD 3-Clause
-## (@uref{https://github.com/SLICOT/SLICOT-Reference/blob/main/LICENSE,  License and Disclaimer}).
+## Uses @url{https://github.com/SLICOT/SLICOT-Reference, SLICOT AB13BD and AB13DD},
+## Copyright (c) 1996-2025, SLICOT, available under the BSD 3-Clause
+## (@url{https://github.com/SLICOT/SLICOT-Reference/blob/main/LICENSE,  License and Disclaimer}).
 ## @end deftypefn
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
