@@ -20,7 +20,6 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: October 2009
-## Version: 0.5
 
 function [y, t, x] = __time_response__ (response, args, names, nout)
 
@@ -35,24 +34,25 @@ function [y, t, x] = __time_response__ (response, args, names, nout)
   inv_idx = ! (sys_idx | mat_idx | sty_idx);                        # invalid arguments
 
   if (any (inv_idx))
-    warning ("%s: arguments number %s are invalid and are being ignored", ...
+    warning ("%s: arguments number %s are invalid and are being ignored\n", ...
              response, mat2str (find (inv_idx)(:).'));
   endif
 
   if (nnz (sys_idx) == 0)
-    error ("%s: require at least one LTI model", response);
+    error ("%s: require at least one LTI model\n", response);
   endif
 
-  if (nout > 0 && (nnz (sys_idx) > 1 || any (sty_idx)))
-    print_usage (response);
-  endif
-
-  if (! size_equal (args{sys_idx}))
-    error ("%s: all LTI models must have equal size", response);
+  if (nout > 0)
+    if nnz (sys_idx) > 1
+      error ("%s: with output arguments, only one system is allowed\n", response);
+    endif
+    if any (sty_idx)
+      warning ("%s: with output arguments, all style parameters are ignored\n", response);
+    endif
   endif
 
   if (any (find (sty_idx) < find (sys_idx)(1)))
-    warning ("%s: strings in front of first LTI model are being ignored", response);
+    warning ("%s: strings in front of first LTI model are being ignored\n", response);
   endif
 
   tfinal = [];  dt = [];  x0 = [];                                  # default arguments
@@ -61,7 +61,7 @@ function [y, t, x] = __time_response__ (response, args, names, nout)
     case "initial"
       switch (nnz (mat_idx))
         case 0
-          error ("initial: require initial state vector 'x0'");
+          error ("initial: require initial state vector 'x0'\n");
         case 1
           x0 = args{mat_idx};
         case 2
@@ -72,7 +72,7 @@ function [y, t, x] = __time_response__ (response, args, names, nout)
           print_usage (response);
       endswitch
       if (! is_real_vector (x0))
-        error ("initial: initial state vector 'x0' must be a real-valued vector");
+        error ("initial: initial state vector 'x0' must be a real-valued vector\n");
       endif
 
     case {"step", "impulse", "ramp"}
@@ -88,7 +88,7 @@ function [y, t, x] = __time_response__ (response, args, names, nout)
       endswitch
 
     otherwise
-      error ("time_response: invalid response type '%s'", response);
+      error ("time_response: invalid response type '%s'\n", response);
   endswitch
 
   switch (response)
@@ -120,11 +120,18 @@ function [y, t, x] = __time_response__ (response, args, names, nout)
   [tfinal, dt] = cellfun (@__sim_horizon__, args(sys_idx), {tfinal}, {dt}, "uniformoutput", false);
   tfinal = max ([tfinal{:}]);
 
+  ## handle names and set reasonable names if empty
+  idx_no_name = cellfun (@isempty, names);
+  sys_numbers = find (idx_no_name);
+  names(sys_numbers) = cellstr (arrayfun (@(x) ['Sys ',num2str(x)], ...
+                                sys_numbers(:), "uniformoutput", false));
+
   ## discretizaiton of continuous time systems
   ## do this in state space for more accurate results
   sys_dt = args(sys_idx);
   ct_idx = cellfun (@isct, sys_dt);
   sys_ct = sys_dt(ct_idx);
+  sys_idx_ct = find (ct_idx);
   ## FIXME: ss can not be applied via cellfun ()? Use a for-loop instead
   ##        "lti: subsasgn: invalid subscripted assignment type '()'"
   sys_ctss = cell (size (sys_ct));
@@ -137,22 +144,24 @@ function [y, t, x] = __time_response__ (response, args, names, nout)
       [nz_y, nz_u] = find (sys_ctss{i}.d);
       if ! isempty (nz_y)
         # there is at least one direct feedthrough, prepare a warning message
-        msg = ["System has a direct feedthrough!\n", ...
-               "The impulse %f*delta(t) is omitted in the impulse response\n", ...
-               "from input \"%s\" to output \"%s\""];
+        msg = ["System \"%s\" has direct feedthrough!\n", ...
+               "The impulse %f*delta(t) is omitted in the impulse response ", ...
+               "from input \"%s\" to output \"%s\"\n"];
       endif
-      for jj = 1:length (nz_y)
-        # get the names of all input/output channels with feedthrough
-        in = sys_ctss{i}.inputname{nz_u(jj)};
-        out = sys_ctss{i}.outputname{nz_y(jj)};
-        if isempty (in)
-          in = ['u', num2str(nz_u(jj))];  # default name
-        endif
-        if isempty (out)
-          out = ['y', num2str(nz_y(jj))];  # default name
-        endif
-        # print the warning
-        warning (msg, sys_ctss{i}.d, in, out);
+      for jy = 1:length (nz_y)
+        for ju = 1:length (nz_u)
+          # get the names of all input/output channels with feedthrough
+          in = sys_ctss{i}.inputname{nz_u(ju)};
+          out = sys_ctss{i}.outputname{nz_y(jy)};
+          if isempty (in)
+            in = ['u', num2str(nz_u(ju))];  # default name
+          endif
+          if isempty (out)
+            out = ['y', num2str(nz_y(jy))];  # default name
+          endif
+          # print the warning
+          warning (msg, names{sys_idx_ct(i)}, sys_ctss{i}.d(jy,ju), in, out);
+        endfor
       endfor
       ## compute impulse response for remaining system without feedthrough
       sys_ctss{i}.d = 0*sys_ctss{i}.d;
@@ -199,11 +208,12 @@ function [y, t, x] = __time_response__ (response, args, names, nout)
     case "ramp"
       [y, x] = cellfun (@__ramp_response__, sys_dt, t, "uniformoutput", false);
     otherwise
-      error ("time_response: invalid response type");
+      error ("time_response: invalid response type\n");
   endswitch
 
 
   if (nout == 0)                                        # display plot
+
     ## extract plotting styles
     tmp = cumsum (sys_idx);
     tmp(sys_idx | ! sty_idx) = 0;
@@ -214,23 +224,31 @@ function [y, t, x] = __time_response__ (response, args, names, nout)
     colororder = get (gca, "colororder");
     rc = rows (colororder);
     def = arrayfun (@(k) {"color", colororder(1+rem (k-1, rc), :)}, 1:n_sys, "uniformoutput", false);
-    idx = cellfun (@isempty, sty);
-    sty(idx) = def(idx);
+    idx_no_sty = cellfun (@isempty, sty);
+    sty(idx_no_sty) = def(idx_no_sty);
+    idx_sty = ! idx_no_sty;
 
-    ## get system names for legend
-    leg = cell (1, n_sys);
-    idx = find (sys_idx);
-    for k = 1 : n_sys
-      leg{k} = names{idx(k)};
-    endfor
+    ## get index for system names (legend)
+    leg_idx = find (sys_idx);
 
-    outname = get (args(sys_idx){end}, "outname");
+    ## get max sizes
+    [p, m] = cellfun (@size, args(sys_idx), 'uniformoutput', false);
+    p = cell2mat (p);
+    m = cell2mat (m);
+    rows = max (p);
+    cols = max (m);
+
+    ## get in/outnames, take ui and yi for more than one system
+    if n_sys == 1
+      outname = get (args(sys_idx){1}, "outname");
+      inname = get (args(sys_idx){1}, "inname");
+    else
+      outname = cell(1,rows);
+      inname = cell(1,cols);
+    endif
     outname = __labels__ (outname, "y");
-    inname = get (args(sys_idx){end}, "inname");
     inname = __labels__ (inname, "u");
 
-    [p, m] = size (args(sys_idx){1});
-
     switch (response)
       case "initial"
         str = "Response to Initial Conditions";
@@ -238,55 +256,94 @@ function [y, t, x] = __time_response__ (response, args, names, nout)
         ## yfinal = zeros (p, 1);
       case "step"
         str = "Step Response";
-        cols = m;
         ## yfinal = dcgain (sys_cell{1});
       case "impulse"
         str = "Impulse Response";
-        cols = m;
         ## yfinal = zeros (p, m);
       case "ramp"
         str = "Ramp Response";
-        cols = m;
       otherwise
-        error ("time_response: invalid response type");
+        error ("time_response: invalid response type '%s'\n", response);
     endswitch
-  
-    for i = 1 : p                                   # for every output
-      for j = 1 : cols                              # for every input (except for initial where cols=1)
 
-        if (p != 1 || cols != 1)
-          subplot (p, cols, (i-1)*cols+j);
-        endif
-
-        box on;
-
-        for k = 1 : n_sys                                 # for every system
-          if (ct_idx(k))    # continuous-time system
-            plot (t{k}, y{k}(:, i, j), sty{k}{:});
-          else              # discrete-time system
-            stairs (t{k}, y{k}(:, i, j), sty{k}{:});
-          endif
-          hold on;
-          grid on;
-          if (k == n_sys)
-            axis tight
-            xlim ([0, tfinal]);
-            ylim (__axis_margin__ (ylim))
-            xlabel ("Time [s]");
-            ylabel (outname{i});
-            title (inname{j}, "fontweight", "normal");
-            if n_sys > 1
-              legend (leg)
-            endif
+    ## get last system present in the subplots
+    last_system = zeros (rows, cols);
+    for i = 1 : rows
+      for j = 1 : cols
+        for k = 1 : n_sys
+          if (p(k) >= i) && (m(k) >= j)
+            last_system(i,j) = k;
           endif
         endfor
-
-        hold off;
-     
       endfor
     endfor
 
-    if (p == 1 && m == 1)
+    ## loop over all subplots
+    for i = 1 : rows              # for every output
+      for j = 1 : cols            # for every input (except for initial where cols=1)
+        if last_system(i,j) > 0   # only if there is a system with this in-/output combination
+
+          subplot (rows, cols, (i-1)*cols+j);
+          box on;
+
+          for k = 1 : last_system(i,j)                # for every system for this in-/output
+
+            p_sys = size (args(sys_idx){k}, 1);
+            m_sys = size (args(sys_idx){k}, 2);
+            if (p_sys >= i) && (m_sys >= j)           # only if system has this in-/output
+
+                ## determine the text for the legend if we have more than
+                ## one system but only for the forst subplot were all systems
+                ## are included
+                if (n_sys > 1) && (i == 1) && (j == 1)
+                  ## we need a legend
+                  if (idx_no_sty(k))
+                    ## no style given
+                    sty{k}{end+1} = [';',names{leg_idx(k)},';'];
+                  else
+                    ## already a style given
+                    if (length (strfind (sty{k}{1}, ";")) < 2)
+                      ## no description included
+                      sty{k}{1,1} = [sty{k}{1,1},';',names{leg_idx(k)},';'];
+                    endif
+                  endif
+                endif
+
+                if (ct_idx(k))    # continuous-time system
+                  plot (t{k}, y{k}(:, i, j), sty{k}{:});
+                else              # discrete-time system
+                  [tstep,ystep] = stairs (t{k}, y{k}(:, i, j));
+                  plot (tstep, ystep, sty{k}{:});
+                endif
+                hold on;
+                if k == last_system(i,j)
+                  ## do the following only for last system in this subplot
+                  grid on;
+                  axis tight
+                  xlim ([0, tfinal]);
+                  ylim (__axis_margin__ (ylim))
+                  xlabel ("Time [s]");
+                  ylabel (outname{i});
+                  if (! strcmp (response, "initial")) && (rows > 1 || cols > 1)
+                    title (inname{j}, "fontweight", "normal");
+                  endif
+                endif
+
+            endif
+
+          endfor
+
+          hold off;
+
+        endif
+
+        hold off;
+
+      endfor
+
+    endfor
+
+    if (rows == 1 && cols == 1)
       title (str);  # normal title
     else
       # create title manually (create axes object on whole figure and put text)
@@ -321,7 +378,7 @@ function [y, x_arr] = __initial_response__ (sys_dt, t, x0)
   x = reshape (x0, [], 1);                              # make sure that x is a column vector
 
   if (n != length (x0) || ! is_real_vector (x0))
-    error ("initial: x0 must be a real vector with %d elements", n);
+    error ("initial: x0 must be a real vector with %d elements\n", n);
   endif
 
   ## simulation
@@ -366,10 +423,8 @@ endfunction
 
 function [y, x_arr] = __impulse_response__ (sys, sys_dt, t)
 
- # [~, B] = ssdata (sys);
   [F, G, C, D, dt] = ssdata (sys_dt);                   # system must be proper
   dt = abs (dt);                                        # use 1 second if tsam is unspecified (-1)
-  discrete = ! isct (sys_dt);
 
   n = rows (F);                                         # number of states
   m = columns (G);                                      # number of inputs
@@ -381,21 +436,15 @@ function [y, x_arr] = __impulse_response__ (sys, sys_dt, t)
   x_arr = zeros (l_t, n, m);
 
   for j = 1 : m                                         # for every input channel
-    ## initial conditions
+
     u = zeros (m, 1);
     u(j) = 1;
 
-    if (discrete)
-      x = zeros (n, 1);                                 # zero by definition
-      y(1, :, j) = D * u / dt;
-      x_arr(1, :, j) = x;
-      x = G * u / dt;
-    else
-      x = G * u;                                        #NO NO B, not G!
-      y(1, :, j) = C * x;
-      x_arr(1, :, j) = x;
-      x = F * x;
-    endif
+    ## initial conditions
+    x = zeros (n, 1);                                 # zero by definition
+    y(1, :, j) = D * u / dt;                          # impulse is 1/dt
+    x_arr(1, :, j) = x;
+    x = G * u / dt;
 
     ## simulation
     for k = 2 : l_t
@@ -403,12 +452,8 @@ function [y, x_arr] = __impulse_response__ (sys, sys_dt, t)
       x_arr(k, :, j) = x;
       x = F * x;
     endfor
-  endfor
 
-  if (discrete)
-    y *= dt;
-    x_arr *= dt;
-  endif
+  endfor
 
 endfunction
 
@@ -471,6 +516,7 @@ function [tfinal, dt] = __sim_horizon__ (sys, tfinal, Ts)
         ev(k) = 2 / Ts * (pol - 1) / (pol + 1);
       endif
     endfor
+  TOL = max (abs (ev))*1.0e-10 + 2*eps;                 # new TOL after bilinear transformation
   endif
 
   ## remove poles near zero from eigenvalue array ev
@@ -513,7 +559,7 @@ function [tfinal, dt] = __sim_horizon__ (sys, tfinal, Ts)
     auto_tfinal = 0;  % flag for computed or given tfinal
 
     if (isempty (tfinal))
-      ev_min = min (abs (real (ev)));
+      ev_min = min (abs (ev));
       ev_real_min = min (abs (real (ev)));
 
       den = min ([ev_min, ev_real_min]);
