@@ -27,12 +27,10 @@
 ## approximates the one from original system @var{G}.
 ##
 ## BTA is an absolute error method which tries to minimize
-## @iftex
 ## @tex
-## $$ || G - G_r ||_{\\infty} = \\min $$
-## $$ || V \\ (G - G_r) \\ W ||_{\\infty} = \\min $$
+## $$ || G - G_r ||_{\infty} = \min $$
+## $$ || V \ (G - G_r) \ W ||_{\infty} = \min $$
 ## @end tex
-## @end iftex
 ## @ifnottex
 ## @example
 ## ||G-Gr||    = min
@@ -201,40 +199,38 @@
 ## Lower guaranteed error bound
 ## @item
 ## Guaranteed a priori error bound
-## @iftex
 ## @tex
-## $$ \\sigma_{r+1} \\leq || (G-G_r) ||_{\\infty} \\leq 2 \\sum_{j=r+1}^{n} \\sigma_j $$
+## $$ \sigma_{r+1} \leq || (G-G_r) ||_{\infty} \leq 2 \sum_{j=r+1}^{n} \sigma_j $$
 ## @end tex
-## @end iftex
 ## @end itemize
 ##
-##
 ## @strong{References}@*
-## [1] Enns, D.
+## @enumerate
+## @item Enns, D.
 ## @cite{Model reduction with balanced realizations: An error bound
 ## and a frequency weighted generalization}.
 ## Proc. 23-th CDC, Las Vegas, pp. 127-132, 1984.
-##
-## [2] Lin, C.-A. and Chiu, T.-Y.
+## @item
+## Lin, C.-A. and Chiu, T.-Y.
 ## @cite{Model reduction via frequency-weighted balanced realization}.
 ## Control Theory and Advanced Technology, vol. 8,
 ## pp. 341-351, 1992.
-##
-## [3] Sreeram, V., Anderson, B.D.O and Madievski, A.G.
+## @item
+## Sreeram, V., Anderson, B.D.O and Madievski, A.G.
 ## @cite{New results on frequency weighted balanced reduction
 ## technique}.
 ## Proc. ACC, Seattle, Washington, pp. 4004-4009, 1995.
-##
-## [4] Varga, A. and Anderson, B.D.O.
+## @item
+## Varga, A. and Anderson, B.D.O.
 ## @cite{Square-root balancing-free methods for the frequency-weighted
 ## balancing related model reduction}.
 ## (report in preparation)
-##
+## @end enumerate
 ##
 ## @strong{Algorithm}@*
-## Uses @uref{https://github.com/SLICOT/SLICOT-Reference, SLICOT AB09ID},
-## Copyright (c) 2020, SLICOT, available under the BSD 3-Clause
-## (@uref{https://github.com/SLICOT/SLICOT-Reference/blob/main/LICENSE,  License and Disclaimer}).
+## Uses @url{https://github.com/SLICOT/SLICOT-Reference, SLICOT AB09ID},
+## Copyright (c) 1996-2025, SLICOT, available under the BSD 3-Clause
+## (@url{https://github.com/SLICOT/SLICOT-Reference/blob/main/LICENSE,  License and Disclaimer}).
 ## @end deftypefn
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
