@@ -129,9 +129,9 @@
 ## @end table
 ##
 ## @strong{Algorithm}@*
-## Uses @uref{https://github.com/SLICOT/SLICOT-Reference, SLICOT SB16BD},
-## Copyright (c) 2020, SLICOT, available under the BSD 3-Clause
-## (@uref{https://github.com/SLICOT/SLICOT-Reference/blob/main/LICENSE,  License and Disclaimer}).
+## Uses @url{https://github.com/SLICOT/SLICOT-Reference, SLICOT SB16BD},
+## Copyright (c) 1996-2025, SLICOT, available under the BSD 3-Clause
+## (@url{https://github.com/SLICOT/SLICOT-Reference/blob/main/LICENSE,  License and Disclaimer}).
 ## @end deftypefn
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
