@@ -19,13 +19,26 @@
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {@var{W} =} gram (@var{sys}, @var{mode})
 ## @deftypefnx {Function File} {@var{Wc} =} gram (@var{a}, @var{b})
+##
 ## @code{gram (@var{sys}, "c")} returns the controllability gramian of
 ## the (continuous- or discrete-time) system @var{sys}.
 ## @code{gram (@var{sys}, "o")} returns the observability gramian of the
 ## (continuous- or discrete-time) system @var{sys}.
 ## @code{gram (@var{a}, @var{b})} returns the controllability gramian
-## @var{Wc} of the continuous-time system @math{dx/dt = a x + b u};
-## i.e., @var{Wc} satisfies @math{a Wc + m Wc' + b b' = 0}.
+## @var{Wc} of the continuous-time system
+## @tex
+## \(\dot{x} = A x + B u\)
+## @end tex
+## @ifnottex
+## @math{dx/dt = A x + B u};
+## @end ifnottex
+## i.e., @var{Wc} satisfies
+## @tex
+## \(A\, Wc + m Wc^T + B\,B^T = 0\).
+## @end tex
+## @ifnottex
+## @math{A Wc + m Wc' + B B' = 0}.
+## @end ifnottex
 ##
 ## @end deftypefn
 
