@@ -22,9 +22,9 @@
 ## @deftypefnx {Function File} ltimodels (@var{systype})
 ## Test suite and help for @acronym{LTI} models.
 ##
-## Some test are based on the @uref{https://github.com/SLICOT/SLICOT-Reference, SLICOT library},
-## Copyright (c) 2020, SLICOT, available under the BSD 3-Clause
-## (@uref{https://github.com/SLICOT/SLICOT-Reference/blob/main/LICENSE,  License and Disclaimer}).
+## Some test are based on the @url{https://github.com/SLICOT/SLICOT-Reference, SLICOT library},
+## Copyright (c) 1996-2025, SLICOT, available under the BSD 3-Clause
+## (@url{https://github.com/SLICOT/SLICOT-Reference/blob/main/LICENSE,  License and Disclaimer}).
 ##
 ## @end deftypefn
 
