@@ -56,7 +56,7 @@
 ## Transfer function model.
 ## @end table
 ##
-## @seealso{tf, ss, dss, frd}
+## @seealso{@@tf/tf, @@ss/ss, dss, @@frd/frd}
 ## @end deftypefn
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
@@ -137,4 +137,4 @@ function sys = zpk (varargin)
 
   sys = tf (num, den, tsam, varargin{:});
 
-endfunction
\ No newline at end of file
+endfunction
